==> tatoo_1.0.10.tar.gz: tatoo/README.md <==
# tatoo

[![CRAN status](http://www.r-pkg.org/badges/version/tatoo)](https://cran.r-project.org/package=tatoo)

There were some minor issues with the last tatoo version that CRAN didn't like. I hope to get it back up asap.

## Overview

tatoo ("table tools") provides functions to combine data.frames in ways that 
require additional effort in base R, and to add metadata (id, title, ...) 
that can be used for printing and xlsx export. The 'Tatoo_report' class is 
provided as a convenient helper to write several such tables to a workbook, 
one table per worksheet. In addition, the `Tatto_report`
class is provided as a convenient helper to write several such tables to a 
workbook, one table per worksheet.
  
  
## Installation

``` r
# tatoo is available from CRAN
install.packages("tatoo")

# Or you can install the development version from GitHub:
install.packages("devtools")
devtools::install_github("statistikat/tatoo")
```

  
## Example

```R
tag_table(head(cars), tt_meta(table_id = "t1", title = "Data about cars"))
mash_table(head = head(cars), tail = tail(cars), mash_method = "row")
mash_table(head = head(cars), tail = tail(cars), mash_method = "col")
comp_table(head = head(cars), tail = tail(cars))
stack_table(head = head(cars), tail = tail(cars))
```

None of the examples are particularily hard to do in base R, but tatoo provides
functions with a clean interface and nice print and export methods for the 
created objects. Please refer to the package 
[vignette](http://rpubs.com/hoelk/261807) for more examples.

==> tatoo_1.1.1.tar.gz: tatoo/README.md <==
# tatoo

[![CRAN status](http://www.r-pkg.org/badges/version/tatoo)](https://cran.r-project.org/package=tatoo)
[![lifecycle](https://img.shields.io/badge/lifecycle-stable-brightgreen.svg)](https://www.tidyverse.org/lifecycle/#stable)

## Overview

tatoo ("table tools") provides functions to combine data.frames in ways that 
require additional effort in base R, and to add metadata (id, title, ...) 
that can be used for printing and xlsx export. In addition, the `Tatto_report`
class is provided as a convenient helper to write several such tables to a 
workbook, one table per worksheet.
  
  
## Installation

``` r
# tatoo is available from CRAN
install.packages("tatoo")

# Or you can install the development version from GitHub:
install.packages("devtools")
devtools::install_github("statistikat/tatoo")
```

  
## Example

```R
tag_table(head(cars), tt_meta(table_id = "t1", title = "Data about cars"))
mash_table(head = head(cars), tail = tail(cars), mash_method = "row")
mash_table(head = head(cars), tail = tail(cars), mash_method = "col")
comp_table(head = head(cars), tail = tail(cars))
stack_table(head = head(cars), tail = tail(cars))
```

None of the examples are particularily hard to do in base R, but tatoo provides
functions with a clean interface and nice print and export methods for the 
created objects. Please refer to the package 
[vignette](http://rpubs.com/hoelk/261807) for more examples.



## Development Status

tatoo is stable and in maintenance mode. While tatoo is effective
at what it does once you figure out how it works, the API is not as nice and
intuitive as I intended it to be. It will continue to receive small updates and 
bugfixes, but it is not planned to implement new features (though if you have
sensible feature requests you are still encouraged to file an issue).
